@@ -173,6 +173,9 @@ srl_build_decoder_struct(pTHX_ HV *opt)
         if ( (svp = hv_fetchs(opt, "refuse_objects", 0)) && SvTRUE(*svp))
             SRL_DEC_SET_OPTION(dec, SRL_F_DECODER_REFUSE_OBJECTS);
 
+        if ( (svp = hv_fetchs(opt, "no_bless_objects", 0)) && SvTRUE(*svp))
+            SRL_DEC_SET_OPTION(dec, SRL_F_DECODER_NO_BLESS_OBJECTS);
+
         if ( (svp = hv_fetchs(opt, "validate_utf8", 0)) && SvTRUE(*svp))
             SRL_DEC_SET_OPTION(dec, SRL_F_DECODER_VALIDATE_UTF8);
 
@@ -400,6 +403,7 @@ srl_read_header(pTHX_ srl_decoder_t *dec)
 SRL_STATIC_INLINE void
 srl_finalize_structure(pTHX_ srl_decoder_t *dec)
 {
+    int nobless = SRL_DEC_HAVE_OPTION(dec, SRL_F_DECODER_NO_BLESS_OBJECTS);
     if (dec->weakref_av)
         av_clear(dec->weakref_av);
     if (dec->ref_stashes) {
@@ -430,7 +434,8 @@ srl_finalize_structure(pTHX_ srl_decoder_t *dec)
 #if USE_588_WORKAROUND
                         /* was blessed early, don't rebless */
 #else
-                        sv_bless(obj, stash);
+                        if (!nobless)
+                            sv_bless(obj, stash);
 #endif
                     } else {
                         SRL_ERROR("object missing from ref_bless_av array?");
@@ -885,7 +890,8 @@ srl_read_objectv(pTHX_ srl_decoder_t *dec, SV* into)
     stash= PTABLE_fetch(dec->ref_stashes, (void *)ofs);
     if (stash == NULL)
         SRL_ERROR("Corrupted packet. OBJECTV used without preceding OBJECT to define classname");
-    sv_bless(into, stash);
+    if (!SRL_DEC_HAVE_OPTION(dec, SRL_F_DECODER_NO_BLESS_OBJECTS))
+        sv_bless(into, stash);
 #endif
 
     /* and also stuff it into the av - we dont have to do any more book-keeping */
@@ -993,7 +999,8 @@ srl_read_object(pTHX_ srl_decoder_t *dec, SV* into)
 
 #if USE_588_WORKAROUND
     /* See 'define USE_588_WORKAROUND' above for a discussion of what this does. */
-    sv_bless(into, stash);
+    if (!SRL_DEC_HAVE_OPTION(dec, SRL_F_DECODER_NO_BLESS_OBJECTS))
+        sv_bless(into, stash);
 #endif
 }
 
